/***********************************************************************/
// MazeDemo:  Try out the Maze class:  read in a maze, count the number of 
//   open cells using a doubly-nested loop, count the number of cells 
//   reachable from a given starting location, or find a path from a given 
//   starting location to a goal cell ...
/***********************************************************************/
import java.io.*;
class MazeDemo
{

    // Admissible maze characters ...

    // For marking a cell as containing part of a wall of the maze ...
    public static final char WALL = 'X';
    // For marking a cell as open ...
    public static final char OPEN = ' ';
    // For marking a cell as part of the path to the goal cell ..
    // For marking the goal cell ...
    public static final char GOAL = 'G';
    // For marking a cell as visited ...
    public static final char MARKED = '.';
    // For marking a path to the maze destination ...
    public static final char PATHMARK = '*';

    // Flags ..

    // Return value for indicating that a recursive call found the goal ...
    public static final boolean FOUND = true;
    // Return value for indicating that a recursive call didn't find the goal
    public static final boolean NOTFOUND = false;

    public static void main (String [] args)
    {
        try
        {
            String filename;            //name of maze data file
            String line;                //holds a line of input
            int startRow, startColumn;  // starting location for maze traversal
            int choice;                 //menu option choice

            BufferedReader console =
               new BufferedReader(new InputStreamReader(System.in));
    
            System.out.print("Enter name of maze data file: ");
            filename = console.readLine();
            System.out.print ("\n" + filename + "\n\n\n");
        
            MazeInterface Labyrinth = new Maze (filename);
            System.out.println(Labyrinth);

            System.out.print ("Enter row of starting location: ");
            line = console.readLine();
            line = line.trim();
            startRow = Integer.parseInt(line);

            System.out.print ("Enter column of starting location: ");
            line = console.readLine();
            line = line.trim();
            startColumn = Integer.parseInt(line);

            do
            {
                System.out.println ("\n\n***********************");
                System.out.println ("    MENU\n\n");
                System.out.println ("1.  Count empty cells");
                System.out.println ("2.  Find goal");
                System.out.println ("0.  Exit");

                System.out.print ("\n    Which?: ");
                line = console.readLine();
                line = line.trim();
                choice = Integer.parseInt(line);
                System.out.println("\n" + choice);
            }
            while (choice < 0 || choice > 2);

            if (choice == 1) 
            {
                int cells = Labyrinth.countCellsFrom(startRow, startColumn);
                System.out.println(Labyrinth);
                System.out.print ("\nThere were " + cells + 
                           " empty cells reachable from the start location\n\n\n");
            }
            else if (choice == 2)
            {
                Labyrinth.findGoal(startRow, startColumn);
                System.out.println
                  ("\n\n*****************************************************");
                System.out.print
                  ("\nA path from the starting location to a ");
                System.out.print (GOAL);
                System.out.print (" character is indicated by ");
                System.out.print(PATHMARK);
                System.out.print(" characters:\n\n");
                System.out.println(Labyrinth);
            }
       }
       catch (FileNotFoundException e)
       {
           System.out.print("\n\n");
           System.out.println(e.getMessage());
           System.out.print("\n\n");
           System.exit(0);
       }
       catch(IOException e)
       {
           System.out.print("\n\n");
           System.out.println(e.getMessage());
           System.out.print("\n\n");
           System.exit(0);
       }
    }
}
