public interface MazeInterface extends CharMatrixInterface
{
    // Admissible maze characters ...

    // For marking a cell as containing part of a wall of the maze ...
    public static final char WALL = 'X';
    // For marking a cell as open ...
    public static final char OPEN = ' ';
    // For marking the goal cell ...
    public static final char GOAL = 'G';
    // For marking a cell as visited ...
    public static final char MARKED = '.';
    // For marking a path to the maze destination ...
    public static final char PATHMARK = '*';

    // Flags ..

    // Return value for indicating that a recursive call found the goal ...
    public static final boolean FOUND = true;
    // Return value for indicating that a recursive call didn't find the goal
    public static final boolean NOTFOUND = false;

    // Precondition:  the entry in row curRow and column curColumn is
    // an open cell (it stores the value OPEN).
    // Postcondition:  All cells reachable from this location have
    // through open cells have been reassigned the value MARKED, they
    // have been counted, and this count has been returned as the return
    // value.
    //
    // To avoid tripping up our grading script, I need to put some constraints
    // on the inner workings of the algorithm, which would not normally be 
    // part of a postcondition/postcondition pair.  See the handout sheet.
    public int countCellsFrom (int curRow, int curColumn);

    // Precondition:  Same as for countCellsFrom.
    // Postcondition:  If there is a path from the entry at (curRow,CurColumn)
    //  to an entry labeled GOAL through open cells, the cells on the path 
    //  should be reassigned to be PATHMARK characters.  Other entries may be 
    //  marked with MARKED characters.  The returned value is true if
    //  a path to a GOAL cell was found, and false otherwise.
    //
    // To avoid tripping up the grading script, in the handout sheet,
    //  we place constraints, similar to the ones for countCellsFrom, on 
    //  the inner workings of the algorithm
    public boolean findGoal(int curRow, int curColumn);
}
